@@ -72,8 +72,8 @@ function change_pass_readfb($pop_socket, &$result, &$messages, $debug) {
 
    if (!feof($pop_socket)) {
       $strResp = fgets($pop_socket, 1024);
-      $result  = trim(substr($strResp, 0, 3));  // 200, 500
-      if (($result != '200' && $result != '300') || $debug) {
+      $result  = substr(trim($strResp), 0, 3);  // 200, 500
+      if(!preg_match('/^[23]\d\d/', $result) || $debug) {
           $messages[] = "--> $strResp";
       }
    }
@@ -126,21 +126,21 @@ function change_pass_go($password, $debug) {
     }
 
     change_pass_readfb($pop_socket, $result, $messages, $debug);
-    if ($result != '200') {
+    if(!preg_match('/^2\d\d/', $result) ) {
         change_pass_closeport($pop_socket, $messages, $debug);
         return $messages;
     }
 
     fputs($pop_socket, "user $username\r\n");
     change_pass_readfb($pop_socket, $result, $messages, $debug);
-    if ($result != '200' && $result != '300') {
+    if(!preg_match('/^[23]\d\d/', $result) ) {
         change_pass_closeport($pop_socket, $messages, $debug);
         return $messages;
     }
 
     fputs($pop_socket, "pass $password\r\n");
     change_pass_readfb($pop_socket, $result, $messages, $debug);
-    if ($result != '200') {
+    if(!preg_match('/^2\d\d/', $result) ) {
         change_pass_closeport($pop_socket, $messages, $debug);
         return $messages;
     }
@@ -148,7 +148,7 @@ function change_pass_go($password, $debug) {
     fputs($pop_socket, "newpass $cp_newpass\r\n");
     change_pass_readfb($pop_socket, $result, $messages, $debug);
     change_pass_closeport($pop_socket, $messages, $debug);
-    if ($result != '200')
+    if(!preg_match('/^2\d\d/', $result) )
         return $messages;
 
     //if ($debug) {
